Changelog
=========


0.1.0
-----

- Add coverage

0.0.3
-----

- Remove hmac_signature upper process logic

0.0.2
-----

- Support Envoy webhook callback authentication

0.0.1
-----

- Initial public release
